=======
History
=======

1.0.1 (2019-11-22)
------------------

* Bump Python support to 3.8 / `Pull request #65 <https://github.com/glenjarvis/badgr-lite/pull/65>`_
* Refactor models.py for clarity / `Pull request #64 <https://github.com/glenjarvis/badgr-lite/pull/64>`_
* Update pluggy to 0.13.1 / `Pull request #62 <https://github.com/glenjarvis/badgr-lite/pull/62>`_
* Update twine to 3.0.0 / `Pull request #60 <https://github.com/glenjarvis/badgr-lite/pull/60>`_
* Update tox to 3.14.1 / `Pull request #59 <https://github.com/glenjarvis/badgr-lite/pull/59>`_
* Update urllib3 to 1.25.7 / `Pull request #58 <https://github.com/glenjarvis/badgr-lite/pull/58>`_
* Update tqdm to 4.38.0 / `Pull request #57 <https://github.com/glenjarvis/badgr-lite/pull/57>`_
* Update astroid to 2.3.3 / `Pull request #56 <https://github.com/glenjarvis/badgr-lite/pull/56>`_
* Update six to 1.13.0 / `Pull request #55 <https://github.com/glenjarvis/badgr-lite/pull/55>`_
* Update pyparsing to 2.4.3 / `Pull request #53 <https://github.com/glenjarvis/badgr-lite/pull/53>`_
* Remove Python 3.5 caveat in README / `Pull request #52 <https://github.com/glenjarvis/badgr-lite/pull/52>`_
* Update vcrpy to 2.1.1 / `Pull request #51 <https://github.com/glenjarvis/badgr-lite/pull/51>`_
* Update tqdm to 4.37.0 / `Pull request #50 <https://github.com/glenjarvis/badgr-lite/pull/50>`_
* Update typing-extensions to 3.7.4.1 / `Pull request #48 <https://github.com/glenjarvis/badgr-lite/pull/48>`_
* Update sphinx to 2.2.1 / `Pull request #46 <https://github.com/glenjarvis/badgr-lite/pull/46>`_
* Update virtualenv to 16.7.7 / `Pull request #45 <https://github.com/glenjarvis/badgr-lite/pull/45>`_
* Update mypy-extensions to 0.4.3 / `Pull request #42 <https://github.com/glenjarvis/badgr-lite/pull/42>`_
* Update mypy 0.740 / `Pull request #40 <https://github.com/glenjarvis/badgr-lite/pull/40>`_
* Update virtualenv to 16.7.6 / `Pull request #39 <https://github.com/glenjarvis/badgr-lite/pull/39>`_
* Reorder README shields / `Pull request #36 <https://github.com/glenjarvis/badgr-lite/pull/36>`_
* Add code coverage / `Pull request #35 <https://github.com/glenjarvis/badgr-lite/pull/35>`_
* Promote package to production level quality / `Pull request #33 <https://github.com/glenjarvis/badgr-lite/pull/33>`_
* Update shield so travis looks at develop branch / `Pull request #31 <https://github.com/glenjarvis/badgr-lite/pull/31>`_
* Update dependencies / `Pull request #30 <https://github.com/glenjarvis/badgr-lite/pull/30>`_
* Update mypy-extensions to 0.4.2 / `Pull request #29 <https://github.com/glenjarvis/badgr-lite/pull/29>`_

1.0.0 (2019-10-03)
------------------
    
* Remove Travis support for Python 3.5 / `Pull request #27 <https://github.com/glenjarvis/badgr-lite/pull/27>`_
* Update snowballstemmer to 2.0.0 / `Pull request #24 <https://github.com/glenjarvis/badgr-lite/pull/24>`_
* [Fixes: #25] Remove support for Python 3.5 / `Pull request #26 <https://github.com/glenjarvis/badgr-lite/pull/26>`_
* Update astroid to 2.3.1 / `Pull request #22 <https://github.com/glenjarvis/badgr-lite/pull/22>`_
* [Fixes #20] Upgrade tox to 3.14.0 / `Pull request #21 <https://github.com/glenjarvis/badgr-lite/pull/21>`_
* [Fixes #18] Fix README shields / `Pull request #19 <https://github.com/glenjarvis/badgr-lite/pull/19>`_

0.0.1 (2019-09-26)
------------------

* First release on PyPI.
